=======================
 Configuration Options
=======================

oslo.service uses oslo.config to define and manage configuration options
to allow the deployer to control how an application uses this library.

periodic_task
=============

These options apply to services using the periodic task features of
oslo.service.

.. show-options:: oslo.service.periodic_task

service
=======

These options apply to services using the basic service framework.

.. show-options:: oslo.service.service

sslutils
========

These options apply to services using the SSL utilities module.

.. show-options:: oslo.service.sslutils

wsgi
====

These options apply to services using the WSGI (Web Service Gateway
Interface) module.

.. show-options:: oslo.service.wsgi
